!2345678911234567892123456789312345678941234567895123456789612345678971234567898
!        0         0         0         0         0         0         0
!                   
! Module: dpsssrc
!
! Author:  Th. Boller - XMM-SSC-MPE
!          
! Description: Create copy of EPIC MAX-Likelihood detect list
!              create DPSS column ver_flag and ver_comm
!              set source flag not_checked (position 2) to T if 
!                  DET_ML is below threshold 
! 
! Comments: 
! 
! $Id: module.f90,v 1.5 1998/01/13 08:39:15 gvacanti Exp $
!- 
module dpsssrc_mod

  use dal
  use param  
  use errorHandling
  
  implicit none 
  
  private 

  public dpsssrc

contains 
  
  !---------------------------------------------------------------------
  subroutine dpsssrc
  !---------------------------------------------------------------------

  type(DataSetT)                                :: infile, outfile
  type(TableT)                                  :: outtab
  type(ColumnT)                                 :: ver_flag, ver_comm, det_ml
  type(ColumnT)					:: ind_sol

  real(single), dimension(:), pointer 		:: p_detml
  real 						:: thresh

  integer(kind=int32), dimension(:),  pointer	:: indsol

  character(len=1024)      			:: outname

  character(len=12)              		:: pnflag1
  character(len=12)              		:: pnflag2
  character(len=40)              		:: comment
  character(len=31)              		:: xxx
  character(len=6)              		:: tttttt

  integer					   i, nr



 !pointer to input file
  infile = dataset(stringParameter("set"),MODIFY)
  xxx = stringParameter("set")


 !test if, M-L detect list is called TTTTTT = OMSRLI
  write(errstr,*) 'set = ',xxx
  call message(AppMsg,Verbose)

   !get string tttttt
    tttttt = xxx(18:23)
    write(errstr,*) "tttttt = ", tttttt
    call message(AppMsg,Verbose)

   !test for tttttt = EMSRLI
    if (tttttt .eq. "EMSRLI") then
        call message(AppMsg,Verbose," ML list found")
    else
        call error("badInput", "input PPS file is not the EPIC M-L detect list")
    endif




 !make a copy of the input file with prefix flag
!  write (outname,'(a,a)') "flag_",trim(stringParameter("set"))
   write (outname,'(a,a)') trim(stringParameter("prefix")),trim(stringParameter("set"))
  call copyDataset(stringParameter("set"),outname)


 !pointer to file and table 
  outfile = dataSet(outname,MODIFY)
  outtab  = table(outfile,"SRCLIST",MODIFY)

 !create new columns (if not yet there)

  if (hasColumn(outtab,"IND_SOL")) then
  else
    ind_sol  = addColumn(outtab,"IND_SOL",INTEGER32,units="I", &
                         comment="running number")
  endif
  if (hasColumn(outtab,"VER_FLAG")) then
    ver_flag = column(outtab,"VER_FLAG",MODIFY)
  else
    ver_flag = addColumn(outtab,"VER_FLAG",String," ",(/12/))
  endif
  if (hasColumn(outtab,"VER_COMM")) then
    ver_comm = column(outtab,"VER_COMM",MODIFY)
  else
    ver_comm = addColumn(outtab,"VER_COMM",String," ",(/40/))
  endif

 !pointer to column ind_sol and to entries in column
  indsol => int32Data(ind_sol)

 !pointer to column ind_sol and to entries in column
  det_ml = column(outtab,"DET_ML",READ)
  p_detml => real32Data(det_ml)

  nr = numberOfRows(outtab)
  write(errstr,*) 'Number of rows: nr = ',nr
  call message(AppMsg,Verbose)

 !write column ind_sol
  do i = 0, nr - 1
     indsol(i) = i + 1
  enddo


 !write column ver_flag
  pnflag1 = "FFFFFFFFFFFF"
  do i = 0, nr - 1
     call setStringCell(ver_flag, i, pnflag1)
  enddo


 !write column ver_comm
  comment = ".                                       "
  do i = 0, nr - 1
     call setStringCell(ver_comm, i, comment)
  enddo



 !make flag setting for not_checked sources
  thresh = realParameter("maxlikthresh")
  pnflag2 = "FTFFFFFFFFFF"
  do i = 0, nr - 1
    if (p_detml(i) < thresh) then 
         call setStringCell(ver_flag, i, pnflag2)
    endif
  enddo


 !release columns
  call release (ind_sol)
  call release (ver_flag)
  call release (ver_comm)
  call release (det_ml)
  call release (outtab)
  call release (outfile)


  end subroutine dpsssrc
  !---------------------------------------------------------------------


end module dpsssrc_mod
